window.Gleam.initSearch([{"doc":"lustre_hash_state","title":"lustre_hash_state","content":"# lustre_hash_state\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_hash_state)](https://hex.pm/packages/lustre_hash_state)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_hash_state/)\n\n---\n\n`lustre_hash_state` provides `Effect`s to store a model&#39;s state in the\nhash fragment:\n\n```\ntype Model {\n  Model(dict.from_list([#(&quot;example_key&quot;, &quot;example_value&quot;)]))\n}\n```\n\n```txt\nhttps://example.com/#example_key=example_value\n```\n\nWhen the model changes, the hash changes! When the hash changes, the model changes, too!\n\n## Usage\n\n```sh\ngleam add lustre_hash_state\n```\n\n```gleam\nimport lustre_hash_state\n\npub opaque type Msg {\n  // ...\n  // Bring your own key value Msg type\n  HashChange(key: String, value: String)\n}\n\nfn init(_flags) -&gt; #(Model, effect.Effect(Msg)) {\n  // dispatch a HashChange Msg when the &quot;hashchange&quot; event is\n  // dispatched from the browser\n  #(Model(dict.new()), lustre_hash_state.init(HashChange))\n}\n\nfn update(model: Model, msg: Msg) -&gt; #(Model, effect.Effect(msg)) {\n  let Model(dct) = model\n  case msg {\n    // update the model on hashchange events\n    HashChange(key, value) -&gt; {\n      #(Model(dict.update(dct, key, fn(_x) { value })), effect.none())\n    }\n    UserUpdatedMessage(key, value) -&gt; {\n      #(\n        Model(dict.update(dct, key, fn(_x) { value })),\n        // update the hash with the new key value pair\n        lustre_hash_state.update(key, value),\n      )\n    }\n  }\n}\n\nfn view(model: Model) -&gt; Element(Msg) {\n  let Model(dct) = model\n\n  ui.group([], [\n    ui.field(\n      [],\n      [element.text(&quot;Write a message:&quot;)],\n      ui.input([\n        attribute.value(result.unwrap(dict.get(dct, &quot;message&quot;), &quot;&quot;)),\n        event.on_input(fn(value) { UserUpdatedMessage(&quot;message&quot;, value) }),\n      ]),\n      [],\n    ),\n  ])\n}\n```\n\n## Encoding\n\nNeed to work with data types more complex than strings? No problem!\n\nWithin lustre&#39;s init fn, decode the data:\n\n```gleam\nfn init(_flags) -&gt; #(Model, effect.Effect(Msg)) {\n  #(\n    Model(dict.new()),\n    lustre_hash_state.init(fn(key: String, value: String) {\n      // decoded using the `from_base64` convenience method\n      HashChange(key, value |&gt; lustre_hash_state.from_base64)\n    }),\n  )\n}\n```\n\nWithin lustre&#39;s update fn, encode the data:\n\n```gleam\nUserUpdatedMessage(key, value) -&gt; {\n  #(\n    Model(...),\n    lustre_hash_state.update(key, value |&gt; lustre_hash_state.to_base64),\n  )\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/lustre_hash_state&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"lustre_hash_state","title":"from_base64","content":"pub fn from_base64(value: String) -&gt; String\n A convenience method to base64 url decode individual values.\n \n ## Example\n \n lustre_hash_state.init(fn(key: String, value: String) {\n   HashChange(key, value |&gt; lustre_hash_state.from_base64)\n })\n \n will dipatch the HashChange msg with the decoded value.\nSynonyms:\nlustre_hash_state.from_base64\nlustre_hash_state from_base64","url":"lustre_hash_state.html#from_base64"},{"doc":"lustre_hash_state","title":"get_hash","content":"pub fn get_hash() -&gt; String\n Returns the current window.location.hash value, including the octothorpe.\n It&#39;s unlikely you&#39;d call this directly, but public for convenience.\nSynonyms:\nlustre_hash_state.get_hash\nlustre_hash_state get_hash","url":"lustre_hash_state.html#get_hash"},{"doc":"lustre_hash_state","title":"init","content":"pub fn init(msg: fn(String, String) -&gt; a) -&gt; Effect(a)\n The effect to be returned in your init method. Sets up hashchange event\n listener and sends messages to update.\n \n ## Example\n \n pub opaque type Msg {\n   HashChange(key: String, value: String)\n }\n\n lustre_hash_state.init(HashChange)\n // or\n lustre_hash_state.init(fn(key: String, value: String) {\n   HashChange(key, value)\n })\n \nSynonyms:\nlustre_hash_state.init\nlustre_hash_state init","url":"lustre_hash_state.html#init"},{"doc":"lustre_hash_state","title":"noop","content":"pub fn noop() -&gt; Effect(a)\n A convenience method identical to effect.none()\nSynonyms:\nlustre_hash_state.noop\nlustre_hash_state noop","url":"lustre_hash_state.html#noop"},{"doc":"lustre_hash_state","title":"parse_hash","content":"pub fn parse_hash(query: String) -&gt; Dict(String, String)\n Parses a query string into a dict\nSynonyms:\nlustre_hash_state.parse_hash\nlustre_hash_state parse_hash","url":"lustre_hash_state.html#parse_hash"},{"doc":"lustre_hash_state","title":"stringify_hash","content":"pub fn stringify_hash(dct: Dict(String, String)) -&gt; String\n Converts a dict to a query string\nSynonyms:\nlustre_hash_state.stringify_hash\nlustre_hash_state stringify_hash","url":"lustre_hash_state.html#stringify_hash"},{"doc":"lustre_hash_state","title":"to_base64","content":"pub fn to_base64(value: String) -&gt; String\n A convenience method to base64 url encode individual values.\n \n ## Example\n \n lustre_hash_state.update(key, value |&gt; lustre_hash_state.to_base64)\n \n will update the hash value as a base64 url encoded string.\nSynonyms:\nlustre_hash_state.to_base64\nlustre_hash_state to_base64","url":"lustre_hash_state.html#to_base64"},{"doc":"lustre_hash_state","title":"update","content":"pub fn update(key: String, value: String) -&gt; Effect(a)\n Updates the hash value.\nSynonyms:\nlustre_hash_state.update\nlustre_hash_state update","url":"lustre_hash_state.html#update"},{"doc":"lustre_hash_state","title":"lustre_hash_state","content":"","url":"lustre_hash_state.html"}]);